Install
=======

From the PyPI
-------------

To install the latest version from the PyPI:

::

   pip install -U apispec


To install with validation support:


::

   pip install -U 'apispec[validation]'

To install with YAML support:

::

   pip install -U 'apispec[yaml]'


Get the Bleeding Edge Version
-----------------------------

To install the latest development version:

::

    pip install -U git+https://github.com/marshmallow-code/apispec@dev
